# Sending Out the Surveys
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/sending-out-surveys#introduction)
  * [Previewing the Survey](https://help.sap.com/docs/leanix/ea/sending-out-surveys#previewing-the-survey)
  * [Defining Survey Recipients](https://help.sap.com/docs/leanix/ea/sending-out-surveys#defining-survey-recipients)
  * [Setting Due Dates for Survey Completion](https://help.sap.com/docs/leanix/ea/sending-out-surveys#setting-due-dates-for-survey-completion)
  * [Creating Survey Emails](https://help.sap.com/docs/leanix/ea/sending-out-surveys#creating-survey-emails)
  * [Testing the Survey](https://help.sap.com/docs/leanix/ea/sending-out-surveys#testing-the-survey)


Preview how the survey looks to the recipient, define the survey recipients based on fact sheet subscription roles, and compose an email invite to distribute the survey.
